==> haskell-src-meta-0.8.14-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src-meta
version:              0.8.14
visibility:           public
id:                   haskell-src-meta-0.8.14-1cXLlG6eHxm4IbWvs5MDqE
key:                  haskell-src-meta-0.8.14-1cXLlG6eHxm4IbWvs5MDqE
license:              BSD-3-Clause
copyright:            (c) Matt Morrow
maintainer:           danburton.email@gmail.com
author:               Matt Morrow
synopsis:             Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.

category:             Language, Template Haskell
abi:                  ec041fc40a56917030b1e37e9cea34e8
exposed:              True
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Extensions
    Language.Haskell.Meta.Parse Language.Haskell.Meta.Syntax.Translate
    Language.Haskell.Meta.Utils

hidden-modules:       Language.Haskell.Meta.THCompat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/haskell-src-meta-0.8.14
library-dirs:         /usr/lib/ghc-9.4.8/site-local/haskell-src-meta-0.8.14
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/haskell-src-meta-0.8.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-meta
hs-libraries:         HShaskell-src-meta-0.8.14-1cXLlG6eHxm4IbWvs5MDqE
depends:
    base-4.17.2.1 haskell-src-exts-1.23.1-AD8tEozqAxMFZGB2XJtuRI
    pretty-1.1.3.6 syb-0.7.2.4-GwVxHFFp6zLBbNId74rfEd
    template-haskell-2.19.0.0 th-orphans-0.13.14-1uWwActsV638XEGw1cU3Vv

haddock-interfaces:
    /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock

haddock-html:         /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-meta-0.8.14-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src-meta
version:              0.8.14
visibility:           public
id:                   haskell-src-meta-0.8.14-IQ5DulFqaJzITukJojivzM
key:                  haskell-src-meta-0.8.14-IQ5DulFqaJzITukJojivzM
license:              BSD-3-Clause
copyright:            (c) Matt Morrow
maintainer:           danburton.email@gmail.com
author:               Matt Morrow
synopsis:             Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.

category:             Language, Template Haskell
abi:                  5f444da4a1c339aa67fa0797d7e030b3
exposed:              True
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Extensions
    Language.Haskell.Meta.Parse Language.Haskell.Meta.Syntax.Translate
    Language.Haskell.Meta.Utils

hidden-modules:       Language.Haskell.Meta.THCompat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/haskell-src-meta-0.8.14
library-dirs:         /usr/lib/ghc-9.4.8/site-local/haskell-src-meta-0.8.14
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/haskell-src-meta-0.8.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-meta
hs-libraries:         HShaskell-src-meta-0.8.14-IQ5DulFqaJzITukJojivzM
depends:
    base-4.17.2.1 haskell-src-exts-1.23.1-1fe4Y0aXIT3HVa2FiDZtj7
    pretty-1.1.3.6 syb-0.7.2.4-5EQR9W4f34Nc1xy39zlm4
    template-haskell-2.19.0.0 th-orphans-0.13.14-BCC4xRfLqzHHZw3x1rej3G

haddock-interfaces:
    /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock

haddock-html:         /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
